﻿/*
 *  Copyright (C) 2016-2025 dean - https://movian.eu
 */

var PREFIX		= 'dashTEST';
var manifest 	= JSON.parse(Plugin.manifest);
var movian_page	= require('movian/page');
var mp4dash		= require('movian/mp4dash'); // needed for mp4_to_hls conversion

var service = require('movian/service').create(manifest.title, PREFIX + ':start', 'video', true, Plugin.path + 'logo.png');

new movian_page.Route(PREFIX + ':start', function(page) 
{
	page.type = 'directory';
	page.contents = 'items';
	page.metadata.icon = Plugin.path + 'logo.png';
	page.metadata.title = manifest.title;

	/*
		This is an example how to create a HLS master + variant playlists
		from non-segmented (non-fragmented) MP4 (MPEG-DASH) files (i.e. YouTube).
		
		Playback of HLS fMP4 for already segmented (HLS sources) is supported
		in M7 7.0.135 - this plugin is not for such sources and purpose.
		
		The plugin will probe 128KB of data from each provided URL
		and will create HLS variants with byte-range offsets for each segment.
		
		The function from movian/mp4dash does the probe, calculates durations and offsets
		and creates master.m3u8/video.m3u8/audio.m3u8 *local* files.
		
		Local storage usage: ~50 - 100 KB (audio/video duration dependent)
		This example will use 5627 bytes (5 KB) to create master/video/audio.m3u8 files
		Bandwidth usage: 128 KB x (number of audio/video tracks)
		
		M7 7.0.138b or newer version is required - why?
			* movian/mp4dash module added to M7 7.0.138b
			* No "#EXT-X-BYTERANGE:SIZE" HLS header support in M7 prior to version 7.0.137
			* No "Range: bytes=X-Y" header support from plugins in M7 prior to version 7.0.136
			* No HLS fMP4 support in M7 prior to version 7.0.135
			
		DASH to HLS does not require DRM7 add-on app and works on all platforms:
		Playstation3, Chrome/NaCl, Linux, MacOS, Android
		
		This plugin does not add playback support for DASH-MPD sources.
			DASH-MPD (XML) parser and MPD-to-HLS on-the-fly converter plugin
			*may be* published at a later stage when enough M7 support is shown.
		
		To support M7 you can donate:
			https://paypal.me/webpluginsBG
	*/

	var dash =
	{
		// prefix playlist file names (not mandatory)
		prefix: 'song1',

		/*	mp4 audio-only source (1 or more) (AAC/AC3/EAC3)
			url: mandatory
		*/
		audio: [
			{
				url: 'https://movian.eu/Android/movianDRM/dashTEST/media/audio.mp4',
				name: 'Track_1',
				lang: 'eng',
			},
			
			/*
			// second audio track
			{
				url: 'https://movian.eu/Android/movianDRM/dashTEST/media/audio2.mp4',
				name: 'Track_2',
				lang: 'spa',
			}
			*/
		],

		/*	mp4 video-only source (1 or more) (AV1/AVC/HEVC)
			url: mandatory
			fps: recommended *if known* (the plugin will try to detect it during the stream probe otherwise)
			other parameters: if not present will default to [1920x1080 detected|25.000fps 3mbit avc1.640028]
		*/
		video: [
			{
				url: 'https://movian.eu/Android/movianDRM/dashTEST/media/video.mp4',
				//width: 854,
				//height: 480,
				//fps: '23.976',
				//bandwidth: 311915,
				//codec: 'avc1.4D401E',
			},
			
			/*
			// second video stream/quality
			{
				url: 'https://movian.eu/Android/movianDRM/dashTEST/media/video2.mp4',
				width: 1280,
				height: 720,
				fps: '24.000',
				bandwidth: 353629,
				codec: 'av01.0.05M.08',
			}
			*/
		],
	};

	/*	Create master/audio/video playlist/m3u8 files (saved under the plugin path + /m3u8/)
		master_m3u8 = file link to the master playlist (local)
		and play the video (M7 7.0.137 required)
	*/
	
	page.loading = 2; /* 2 = smaller clockwise rotating indicator on Android builds */
	
	var master_m3u8 = mp4dash.mp4_to_hls(dash, /*no log*/ 0);

	if(master_m3u8)
	{
		console.log('HLS Master File: ' + master_m3u8);

		/* 1) Open the video/playlist directly

				page.openurl(master_m3u8);
			or
				page.redirect(master_m3u8);

		or 2) Use it as a video page source (like most plugins do)
		*/

		page.type = 'video';
		var videoParams = {
			title: 'Teddy Swims - Show you the door (DASH to HLS Example)',
			sources: [{
				url: master_m3u8,
			}],
			no_subtitle_scan: true,
			no_fs_scan: true,
		}
		page.source = 'videoparams:' + JSON.stringify(videoParams);		
	}
});